@@ -11,9 +11,9 @@ use Data::Printer alias => 'pdump';
 ###############################
 
 has env => (
-    is => 'rw',
-    isa => 'Str|Undef',
-    lazy => 1,
+    is      => 'rw',
+    isa     => 'Str|Undef',
+    lazy    => 1,
     builder => '_build_env',
 );
 
@@ -21,75 +21,80 @@ has env => (
 ###### PRIVATE_ATTRIBUTES ######
 ################################
 
-
 ############################
 ###### PUBLIC METHODS ######
 ############################
 
 method test1_method {
-   return "hello world"; 
+    return "hello world";
 }
 
 method test2_method (Str :$myarg!) {
-    return "test2: $myarg";    
+    return "test2: $myarg";
 }
 
 method test3_method (Str :$myarg!,
                      Str :$softargX) {
 
-    if (!$softargX) {
-        if ($ENV{SOFTARGX}) {
-        # ok 
+    if ( !$softargX ) {
+        if ( $ENV{SOFTARGX} ) {
+
+            # ok
         }
         else {
-            confess;    
+            confess;
         }
-    }     
-    
+    }
+
     return $softargX;
 }
 
 method test4_method (Str :$myarg!,
                      Str :$softargX,
                      Str :$optionalargZ) {
-                         
-    if (!$softargX) {
-        if ($ENV{SOFTARGX}) {
-        # ok 
+
+    if ( !$softargX ) {
+        if ( $ENV{SOFTARGX} ) {
+
+            # ok
         }
         else {
-            confess;    
+            confess;
         }
-    }    
-    
+    }
+
     return $optionalargZ;
 }
 
-
 method test5_method (Str :$myarg!,
                      Str :$softargX,
                      Str :$optionalargZ,
                      Bool :$dry_run) {
-                         
-    if (!$softargX) {
-        if ($ENV{SOFTARGX}) {
-        # ok 
+
+    if ( !$softargX ) {
+        if ( $ENV{SOFTARGX} ) {
+
+            # ok
         }
         else {
-            confess;    
+            confess;
         }
-    }    
-   
-    return $dry_run;     
+    }
+
+    return $dry_run;
 }
-                     
+
+method test15_method (Num :$longarg = 1) {
+    return $longarg;
+}
+
 #############################
 ###### PRIVATE METHODS ######
 #############################
 
 method _build_env {
 
-    if ($ENV{ENV}) {
+    if ( $ENV{ENV} ) {
         return $ENV{ENV};
     }
 }
